@@ -12,6 +12,7 @@ import zlib
 
 import _damo_fmt_str
 import _damon
+import damo_report_access
 
 PERF = 'perf'
 perf_event_damon_aggregated = 'damon:damon_aggregated'
@@ -1395,6 +1396,21 @@ def filter_records_by_snapshot_time(records, time_ranges):
                 filtered_snapshots.append(snapshot)
         record.snapshots = filtered_snapshots
 
+def filter_records_by_temperature(records, temperature_ranges,
+                                  temperature_weights):
+    for record in records:
+        for snapshot in record.snapshots:
+            filtered_regions = []
+            for region in snapshot.regions:
+                temperature = damo_report_access.temperature_of(
+                        region, temperature_weights)
+                for min_t, max_t in temperature_ranges:
+                    if min_t <= temperature and temperature <= max_t:
+                        filtered_regions.append(region)
+                        break
+            snapshot.regions = filtered_regions
+            snapshot.update_total_bytes()
+
 def get_snapshot_records_of(request):
     '''
     get records containing single snapshot from running kdamonds
@@ -1428,13 +1444,17 @@ class RecordFilter:
     address_ranges = None
     snapshot_sz_ranges = None
     snapshot_time_ranges = None
+    temperature_ranges = None
+    temperature_weights = None
 
     def __init__(self, access_pattern, address_ranges, snapshot_sz_ranges,
-                 snapshot_time_ranges):
+                 snapshot_time_ranges, temperature_ranges, temperature_weights):
         self.access_pattern = access_pattern
         self.address_ranges = address_ranges
         self.snapshot_sz_ranges = snapshot_sz_ranges
         self.snapshot_time_ranges = snapshot_time_ranges
+        self.temperature_ranges = temperature_ranges
+        self.temperature_weights = temperature_weights
 
     def to_kvpairs(self, raw):
         kvpairs = {'access_pattern': self.access_pattern.to_kvpairs(raw)}
@@ -1454,6 +1474,8 @@ class RecordFilter:
                      _damo_fmt_str.format_sz(end, raw)]
                     for start, end in self.snapshot_sz_ranges]
         kvpairs['snapshot_sz_ranges'] = snapshot_sz_ranges
+        kvpairs['temperature_ranges'] = self.temperature_ranges
+        kvpairs['temperature_weights'] = self.temperature_weights
         return kvpairs
 
     def filter_records(self, records):
@@ -1466,6 +1488,9 @@ class RecordFilter:
             filter_records_by_snapshot_sz(records, self.snapshot_sz_ranges)
         if self.snapshot_time_ranges is not None:
             filter_records_by_snapshot_time(records, self.snapshot_time_ranges)
+        if self.temperature_ranges is not None:
+            filter_records_by_temperature(records, self.temperature_ranges,
+                                          self.temperature_weights)
 
 class RecordGetRequest:
     # TODO: Extend to be used for recording
@@ -1505,7 +1530,7 @@ def get_records(tried_regions_of=None, record_file=None, record_filter=None,
     if record_filter:
         filter_copy = copy.deepcopy(record_filter)
     else:
-        filter_copy = RecordFilter(None, None, None, None)
+        filter_copy = RecordFilter(None, None, None, None, None, None)
 
     if request.record_file is None:
         records, err = get_snapshot_records_of(request)
@@ -1569,8 +1594,15 @@ def args_to_filter(args):
                 [_damo_fmt_str.text_to_ns(s), _damo_fmt_str.text_to_ns(e)]
                 for s, e in args.snapshot_time]
 
+    if hasattr(args, 'temperature_weights'):
+        temperature_weights = args.temperature_weights
+    else:
+        # ignore size
+        temperature_weights = [0, 100, 100]
+
     return RecordFilter(access_pattern, addr_range,
-                        snapshot_sz_ranges, snapshot_time), None
+                        snapshot_sz_ranges, snapshot_time,
+                        args.temperature, temperature_weights), None
 
 def set_filter_argparser(parser):
     parser.add_argument('--sz_region', metavar=('<min>', '<max>'), nargs=2,
@@ -1593,3 +1625,7 @@ def set_filter_argparser(parser):
             '--snapshot_time', metavar=('<start (ns)>', '<end (ns)>'), nargs=2,
             action='append',
             help='show snapshots generated in these time intervals')
+    parser.add_argument(
+            '--temperature', metavar=('<min>', '<max>'), nargs=2, type=int,
+            action='append',
+            help='min/max temperature of regions to show')
