@@ -107,39 +107,51 @@ snapshot_formatters = [
         ]
 
 region_formatters = [
-        Formatter('<index>',
-            lambda index, region, raw, rbargs:
+        Formatter(
+            '<index>',
+            lambda index, region, raw, fmt, rbargs:
             _damo_fmt_str.format_nr(index, raw),
             'index of the region in the regions of the snapshot'),
-        Formatter('<start address>',
-            lambda index, region, raw, rbargs:
+        Formatter(
+            '<start address>',
+            lambda index, region, raw, fmt, rbargs:
             _damo_fmt_str.format_sz(region.start, raw),
             'start address of the region'),
-        Formatter('<end address>',
-            lambda index, region, raw, rbargs:
+        Formatter(
+            '<end address>',
+            lambda index, region, raw, fmt, rbargs:
             _damo_fmt_str.format_sz(region.end, raw),
             'end address of the region'),
-        Formatter('<size>',
-            lambda index, region, raw, rbargs:
+        Formatter(
+            '<size>',
+            lambda index, region, raw, fmt, rbargs:
             _damo_fmt_str.format_sz(region.size(), raw),
             'size of the region'),
-        Formatter('<access rate>',
-            lambda index, region, raw, rbargs:
+        Formatter(
+            '<access rate>',
+            lambda index, region, raw, fmt, rbargs:
             _damo_fmt_str.format_percent(region.nr_accesses.percent, raw),
             'monitored access rate of the region'),
-        Formatter('<age>',
-            lambda index, region, raw, rbargs:
+        Formatter(
+            '<age>',
+            lambda index, region, raw, fmt, rbargs:
             _damo_fmt_str.format_time_us(region.age.usec, raw),
             'how long the access pattern of the region has maintained'),
-        Formatter('<box>',
-            lambda index, region, raw, rbargs:
+        Formatter(
+            '<temperature>',
+            lambda index, region, raw, fmt, rbargs:
+            temperature_str(region, raw, fmt),
+            'access temperature of the region'),
+        Formatter(
+            '<box>',
+            lambda index, region, raw, fmt, rbargs:
             rbargs.to_str(region),
             'user-customizable (via --region_box_*) box (age/access_rate/size by default)'),
         ]
 
 default_record_head_format = 'kdamond <kdamond index> / context <context index> / scheme <scheme index> / target id <target id> / recorded for <duration> from <abs start time>'
 default_snapshot_head_format = 'monitored time: [<start time>, <end time>] (<duration>)'
-default_region_format = '<index> addr [<start address>, <end address>) (<size>) access <access rate> age <age>'
+default_region_format = '<index> addr <start address> size <size> access <access rate> age <age>'
 
 def temperature_sz_hist_str(snapshot, record, raw, fmt):
     if len(snapshot.regions) == 0:
@@ -171,7 +183,8 @@ def temperature_sz_hist_str(snapshot, record, raw, fmt):
             min_sz = sz
         if max_sz is None or max_sz < sz:
             max_sz = sz
-        trange_str = '[%d, %d)' % (min_t, max_t)
+        trange_str = '[%s, %s)' % (_damo_fmt_str.format_nr(min_t, raw),
+                                   _damo_fmt_str.format_nr(max_t, raw))
         if max_trange_str is None or max_trange_str < len(trange_str):
             max_trange_str = len(trange_str)
         sz_str = _damo_fmt_str.format_sz(sz, raw)
@@ -245,6 +258,10 @@ def recency_hist_str(snapshot, record, raw, fmt):
         lines.append('%s %s %s' % (trange_str, sz_str, bar))
     return '\n'.join(lines)
 
+def temperature_str(region, raw, fmt):
+    temperature = temperature_of(region, fmt.temperature_weights)
+    return _damo_fmt_str.format_nr(temperature, raw)
+
 def region_in(start, end, regions):
     for region in regions:
         if region.end <= start:
@@ -604,7 +621,7 @@ def format_template(template, formatters, min_chars, fmt, index, region,
             txt = formatter.format_fn(snapshot, record, raw, fmt,
                                       region_box_args)
         elif formatters == region_formatters:
-            txt = formatter.format_fn(index, region, raw, region_box_args)
+            txt = formatter.format_fn(index, region, raw, fmt, region_box_args)
         txt = apply_min_chars(min_chars, formatter.keyword, txt)
         template = template.replace(formatter.keyword, txt)
     template = template.replace('\\n', '\n')
